@@ -11,10 +11,13 @@ import system.date
 from com.inductiveautomation.ignition.common import Dataset
 from java.util import Date
 
-from incendium.types import DictStringAny, String
+from incendium.helper.types import DictStringAny, String
 
 
 class _NanoXML(object):
+    indent = None  # type: String
+    root = None  # type: String
+
     def __init__(self, root="root", indent="\t"):
         # type: (String, String) -> None
         """Nano XML initializer.
